@@ -26,7 +26,7 @@ use {
     termimad::{Area, CropWriter, SPACE_FILLING},
 };
 
-/// a homogeneously colored piece of a line
+/// Homogeneously colored piece of a line
 #[derive(Debug)]
 pub struct Region {
     pub fg: Color,
@@ -71,7 +71,7 @@ pub struct SyntacticView {
 
 impl SyntacticView {
 
-    /// return a prepared text view with syntax coloring if possible.
+    /// Return a prepared text view with syntax coloring if possible.
     /// May return Ok(None) only when a pattern is given and there
     /// was an event before the end of filtering.
     pub fn new(
@@ -97,7 +97,7 @@ impl SyntacticView {
         }
     }
 
-    /// return true when there was no interruption
+    /// Return true when there was no interruption
     fn read_lines(
         &mut self,
         dam: &mut Dam,
@@ -135,22 +135,22 @@ impl SyntacticView {
             self.total_lines_count += 1;
             let start = offset;
             offset += line.len();
-            while line.ends_with('\n') || line.ends_with('\r') {
-                line.pop();
-            }
             for c in line.chars() {
                 if !is_char_printable(c) {
                     debug!("unprintable char: {:?}", c);
                     return Err(ProgramError::UnprintableFile);
                 }
             }
+            // We don't remove '\n' or '\r' at this point because some syntax sets
+            // need them for correct detection of comments. See #477
+            // Those chars are removed on printing
             if pattern.is_empty() || pattern.score_of_string(&line).is_some() {
                 let name_match = pattern.search_string(&line);
                 let regions = if let Some(highlighter) = highlighter.as_mut() {
                     highlighter
                         .highlight(&line, &SYNTAXER.syntax_set)
                         .iter()
-                        .map(|r| Region::from_syntect(r))
+                        .map(Region::from_syntect)
                         .collect()
                 } else {
                     Vec::new()
@@ -172,8 +172,8 @@ impl SyntacticView {
         Ok(true)
     }
 
-    /// (count of lines which can be seen when scrolling,
-    /// total count including filtered ones)
+    /// Give the count of lines which can be seen when scrolling,
+    /// total count including filtered ones
     pub fn line_counts(&self) -> (usize, usize) {
         (self.lines.len(), self.total_lines_count)
     }
@@ -323,6 +323,7 @@ impl SyntacticView {
         let match_bg = styles.preview_match.get_bg().unwrap_or(Color::AnsiValue(28));
         let code_width = area.width as usize - 1; // 1 char left for scrollbar
         let scrollbar = area.scrollbar(self.scroll, self.lines.len());
+        debug!("scrollbar: {:#?}", scrollbar);
         let scrollbar_fg = styles.scrollbar_thumb.get_fg()
             .or_else(|| styles.preview.get_fg())
             .unwrap_or(Color::White);
@@ -376,7 +377,7 @@ impl SyntacticView {
                     let pos = &nm.pos;
                     let mut pos_idx: usize = 0;
                     for content in regions {
-                        let s = &content.string;
+                        let s = content.string.trim_end_matches(is_char_end_of_line);
                         cw.w.queue(SetForegroundColor(content.fg))?;
                         if pos_idx < pos.len() {
                             for (cand_idx, cand_char) in s.chars().enumerate() {
@@ -397,7 +398,7 @@ impl SyntacticView {
                 } else {
                     for content in regions {
                         cw.w.queue(SetForegroundColor(content.fg))?;
-                        cw.queue_unstyled_str(&content.string)?;
+                        cw.queue_unstyled_str(content.string.trim_end_matches(is_char_end_of_line))?;
                     }
                 }
             }
@@ -406,7 +407,7 @@ impl SyntacticView {
                 &SPACE_FILLING,
             )?;
             w.queue(SetBackgroundColor(bg))?;
-            if is_thumb(y, scrollbar) {
+            if is_thumb(y + area.top as usize, scrollbar) {
                 w.queue(SetForegroundColor(scrollbar_fg))?;
                 w.queue(Print('▐'))?;
             } else {
@@ -451,9 +452,14 @@ fn is_thumb(y: usize, scrollbar: Option<(u16, u16)>) -> bool {
     })
 }
 
-/// tell whether the character is normal enough to be displayed by the
+/// Tell whether the character is normal enough to be displayed by the
 /// syntactic view (if not we'll use a hex view)
 fn is_char_printable(c: char) -> bool {
     // the tab is printable because it's replaced by spaces
-    c == '\t' || !c.is_control()
+    c == '\t' || c == '\n' || c == '\r' || !c.is_control()
 }
+
+fn is_char_end_of_line(c: char) -> bool {
+    c == '\n' || c == '\r'
+}
+
